@@ -1,6 +1,5 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from __future__ import annotations
 
 from typing import Any
 from ocp_resources.resource import Resource
@@ -22,7 +21,7 @@ class Console(Resource):
         authentication: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
             authentication (dict[str, Any]): ConsoleAuthentication defines a list of optional configuration for
               console authentication.
