@@ -1,13 +1,13 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from __future__ import annotations
+
 from typing import Any
 from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
 
 
 class ServingRuntime(NamespacedResource):
     """
-    No field description from API; please add description
+    No field description from API
     """
 
     api_group: str = NamespacedResource.ApiGroup.SERVING_KSERVE_IO
@@ -34,43 +34,43 @@ class ServingRuntime(NamespacedResource):
         volumes: list[Any] | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
-            affinity (dict[str, Any]): No field description from API; please add description
+            affinity (dict[str, Any]): No field description from API
 
-            spec_annotations (dict[str, Any]): No field description from API; please add description
+            spec_annotations (dict[str, Any]): No field description from API
 
-            built_in_adapter (dict[str, Any]): No field description from API; please add description
+            built_in_adapter (dict[str, Any]): No field description from API
 
-            containers (list[Any]): No field description from API; please add description
+            containers (list[Any]): No field description from API
 
-            disabled (bool): No field description from API; please add description
+            disabled (bool): No field description from API
 
-            grpc_data_endpoint (str): No field description from API; please add description
+            grpc_data_endpoint (str): No field description from API
 
-            grpc_endpoint (str): No field description from API; please add description
+            grpc_endpoint (str): No field description from API
 
-            http_data_endpoint (str): No field description from API; please add description
+            http_data_endpoint (str): No field description from API
 
-            image_pull_secrets (list[Any]): No field description from API; please add description
+            image_pull_secrets (list[Any]): No field description from API
 
-            spec_labels (dict[str, Any]): No field description from API; please add description
+            spec_labels (dict[str, Any]): No field description from API
 
-            multi_model (bool): No field description from API; please add description
+            multi_model (bool): No field description from API
 
-            node_selector (dict[str, Any]): No field description from API; please add description
+            node_selector (dict[str, Any]): No field description from API
 
-            protocol_versions (list[Any]): No field description from API; please add description
+            protocol_versions (list[Any]): No field description from API
 
-            replicas (int): No field description from API; please add description
+            replicas (int): No field description from API
 
-            storage_helper (dict[str, Any]): No field description from API; please add description
+            storage_helper (dict[str, Any]): No field description from API
 
-            supported_model_formats (list[Any]): No field description from API; please add description
+            supported_model_formats (list[Any]): No field description from API
 
-            tolerations (list[Any]): No field description from API; please add description
+            tolerations (list[Any]): No field description from API
 
-            volumes (list[Any]): No field description from API; please add description
+            volumes (list[Any]): No field description from API
 
         """
         super().__init__(**kwargs)
@@ -106,55 +106,55 @@ class ServingRuntime(NamespacedResource):
 
             _spec["containers"] = self.containers
 
-            if self.affinity:
+            if self.affinity is not None:
                 _spec["affinity"] = self.affinity
 
-            if self.spec_annotations:
+            if self.spec_annotations is not None:
                 _spec["annotations"] = self.spec_annotations
 
-            if self.built_in_adapter:
+            if self.built_in_adapter is not None:
                 _spec["builtInAdapter"] = self.built_in_adapter
 
             if self.disabled is not None:
                 _spec["disabled"] = self.disabled
 
-            if self.grpc_data_endpoint:
+            if self.grpc_data_endpoint is not None:
                 _spec["grpcDataEndpoint"] = self.grpc_data_endpoint
 
-            if self.grpc_endpoint:
+            if self.grpc_endpoint is not None:
                 _spec["grpcEndpoint"] = self.grpc_endpoint
 
-            if self.http_data_endpoint:
+            if self.http_data_endpoint is not None:
                 _spec["httpDataEndpoint"] = self.http_data_endpoint
 
-            if self.image_pull_secrets:
+            if self.image_pull_secrets is not None:
                 _spec["imagePullSecrets"] = self.image_pull_secrets
 
-            if self.spec_labels:
+            if self.spec_labels is not None:
                 _spec["labels"] = self.spec_labels
 
             if self.multi_model is not None:
                 _spec["multiModel"] = self.multi_model
 
-            if self.node_selector:
+            if self.node_selector is not None:
                 _spec["nodeSelector"] = self.node_selector
 
-            if self.protocol_versions:
+            if self.protocol_versions is not None:
                 _spec["protocolVersions"] = self.protocol_versions
 
-            if self.replicas:
+            if self.replicas is not None:
                 _spec["replicas"] = self.replicas
 
-            if self.storage_helper:
+            if self.storage_helper is not None:
                 _spec["storageHelper"] = self.storage_helper
 
-            if self.supported_model_formats:
+            if self.supported_model_formats is not None:
                 _spec["supportedModelFormats"] = self.supported_model_formats
 
-            if self.tolerations:
+            if self.tolerations is not None:
                 _spec["tolerations"] = self.tolerations
 
-            if self.volumes:
+            if self.volumes is not None:
                 _spec["volumes"] = self.volumes
 
     # End of generated code
