@@ -1,18 +1,13 @@
 import pytest
-from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.mariadb_operator import MariadbOperator
 
 
 @pytest.mark.incremental
 class TestMariadbOperator:
     @pytest.fixture(scope="class")
-    def client(self):
-        return FakeDynamicClient()
-
-    @pytest.fixture(scope="class")
-    def mariadboperator(self, client):
+    def mariadboperator(self, fake_client):
         return MariadbOperator(
-            client=client,
+            client=fake_client,
             name="test-mariadboperator",
             namespace="default",
         )
